@@ -38,7 +38,7 @@ import aws_cdk.core
 
 
 @jsii.interface(
-    jsii_type="@renovosolutions/aws-cdk-managed-instance-role.IManagedInstanceRoleProps"
+    jsii_type="@renovosolutions/cdk-library-managed-instance-role.IManagedInstanceRoleProps"
 )
 class IManagedInstanceRoleProps(typing_extensions.Protocol):
     @builtins.property # type: ignore[misc]
@@ -81,7 +81,7 @@ class IManagedInstanceRoleProps(typing_extensions.Protocol):
 
 
 class _IManagedInstanceRolePropsProxy:
-    __jsii_type__: typing.ClassVar[str] = "@renovosolutions/aws-cdk-managed-instance-role.IManagedInstanceRoleProps"
+    __jsii_type__: typing.ClassVar[str] = "@renovosolutions/cdk-library-managed-instance-role.IManagedInstanceRoleProps"
 
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="domainJoinEnabled")
@@ -128,7 +128,7 @@ typing.cast(typing.Any, IManagedInstanceRoleProps).__jsii_proxy_class__ = lambda
 class ManagedInstanceRole(
     aws_cdk.core.Construct,
     metaclass=jsii.JSIIMeta,
-    jsii_type="@renovosolutions/aws-cdk-managed-instance-role.ManagedInstanceRole",
+    jsii_type="@renovosolutions/cdk-library-managed-instance-role.ManagedInstanceRole",
 ):
     def __init__(
         self,
